@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -23,12 +23,12 @@ import time
 # external packages
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QWidget
-from PyQt5.QtTest import QTest
 
 # local import
 if packageConfig.isAvailable:
     from gui.extWindows.simulatorW import SimulatorWindow
 
+from gui.utilities.toolsQtWidget import sleepAndEvents
 from gui.extWindows.keypadW import KeypadWindow
 from gui.utilities.stylesQtCss import Styles
 from gui.utilities.toolsQtWidget import MWidget
@@ -759,7 +759,8 @@ class MainWindow(
         else:
             mode = 'Offline Mode'
 
-        t = f'{mode}  -  Active Threads: {self.threadPool.activeThreadCount():2d}'
+        activeCount = self.threadPool.activeThreadCount()
+        t = f'{mode}  -  Active Threads: {activeCount:2d} / 30'
         self.ui.statusOnline.setTitle(t)
 
         tzT = time.tzname[1] if time.daylight else time.tzname[0]
@@ -778,19 +779,19 @@ class MainWindow(
             self.ui.statusText.setText('-')
 
         if self.app.mount.obsSite.status == 0:
-            self.changeStyleDynamic(self.ui.tracking, 'running', 'true')
+            self.changeStyleDynamic(self.ui.tracking, 'running', True)
         else:
-            self.changeStyleDynamic(self.ui.tracking, 'running', 'false')
+            self.changeStyleDynamic(self.ui.tracking, 'running', False)
 
         if self.app.mount.obsSite.status == 5:
-            self.changeStyleDynamic(self.ui.park, 'running', 'true')
+            self.changeStyleDynamic(self.ui.park, 'running', True)
         else:
-            self.changeStyleDynamic(self.ui.park, 'running', 'false')
+            self.changeStyleDynamic(self.ui.park, 'running', False)
 
         if self.app.mount.obsSite.status == 1:
-            self.changeStyleDynamic(self.ui.stop, 'running', 'true')
+            self.changeStyleDynamic(self.ui.stop, 'running', True)
         else:
-            self.changeStyleDynamic(self.ui.stop, 'running', 'false')
+            self.changeStyleDynamic(self.ui.stop, 'running', False)
 
         return True
 
@@ -888,7 +889,7 @@ class MainWindow(
                     continue
 
                 waitDeleted = False
-            QTest.qWait(100)
+            sleepAndEvents(100)
         return True
 
     @staticmethod
