@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -22,13 +22,14 @@ from pathlib import Path
 # external packages
 import PyQt5
 from PyQt5.QtGui import QTextCursor
-from PyQt5.QtTest import QTest
 from astropy.io import fits
 from base.transform import J2000ToJNow
 
 # local import
+from gui.utilities.toolsQtWidget import sleepAndEvents
 from mountcontrol.convert import convertRaToAngle, convertDecToAngle
 from mountcontrol.convert import formatHstrToText, formatDstrToText
+from mountcontrol.convert import valueToFloat
 from mountcontrol.connection import Connection
 
 
@@ -37,6 +38,8 @@ class Tools(object):
     """
 
     def __init__(self):
+        self.targetAlt = None
+        self.targetAz = None
         self.selectorsDropDowns = {'rename1': self.ui.rename1,
                                    'rename2': self.ui.rename2,
                                    'rename3': self.ui.rename3,
@@ -101,8 +104,8 @@ class Tools(object):
         self.clickable(self.ui.moveCoordinateDec).connect(self.setDEC)
         self.ui.moveCoordinateDec.textEdited.connect(self.setDEC)
         self.ui.moveCoordinateDec.returnPressed.connect(self.setDEC)
-
         self.ui.commandInput.returnPressed.connect(self.commandRaw)
+        self.app.mount.signals.slewFinished.connect(self.moveAltAzDefault)
 
     def initConfig(self):
         """
@@ -260,10 +263,8 @@ class Tools(object):
         :param fileName: fits file to be renamed
         :return: success
         """
-
         if not fileName:
             return False
-
         if not os.path.isfile(fileName):
             return False
 
@@ -278,7 +279,6 @@ class Tools(object):
             else:
                 if 'OBJECT' in fitsHeader:
                     newFilename = fitsHeader['OBJECT'].upper()
-
                 else:
                     newFilename = 'UNKNOWN'
 
@@ -291,7 +291,6 @@ class Tools(object):
                     newFilename += f'_{chunk}'
 
             newFilename += '.fits'
-
             dirName = os.path.dirname(fileName)
             newFilename = f'{dirName}/{newFilename}'
             os.rename(fileName, newFilename)
@@ -307,7 +306,6 @@ class Tools(object):
         """
         pathDir = self.ui.renameDir.text()
         includeSubdirs = self.ui.checkIncludeSubdirs.isChecked()
-
         if not os.path.isdir(pathDir):
             self.app.message.emit('No valid input directory given', 2)
             return False
@@ -347,25 +345,29 @@ class Tools(object):
             self.ui.renameProgress.setValue(0)
         return True
 
+    def stopMoveAll(self):
+        """
+        :return: success
+        """
+        for uiR in self.setupMoveClassic:
+            self.changeStyleDynamic(uiR, 'running', False)
+        self.app.mount.obsSite.stopMoveAll()
+        return True
+
     def moveDuration(self):
         """
         :return:
         """
         if self.ui.moveDuration.currentIndex() == 1:
-            QTest.qWait(10000)
-
+            sleepAndEvents(10000)
         elif self.ui.moveDuration.currentIndex() == 2:
-            QTest.qWait(5000)
-
+            sleepAndEvents(5000)
         elif self.ui.moveDuration.currentIndex() == 3:
-            QTest.qWait(2000)
-
+            sleepAndEvents(2000)
         elif self.ui.moveDuration.currentIndex() == 4:
-            QTest.qWait(1000)
-
+            sleepAndEvents(1000)
         else:
             return False
-
         self.stopMoveAll()
         return True
 
@@ -377,6 +379,9 @@ class Tools(object):
         if ui not in self.setupMoveClassic:
             return False
 
+        for uiR in self.setupMoveClassic:
+            self.changeStyleDynamic(uiR, 'running', False)
+
         self.changeStyleDynamic(ui, 'running', True)
         directions = self.setupMoveClassic[ui]
 
@@ -384,7 +389,6 @@ class Tools(object):
             self.app.mount.obsSite.moveNorth()
         elif directions[0] == -1:
             self.app.mount.obsSite.moveSouth()
-
         if directions[1] == 1:
             self.app.mount.obsSite.moveEast()
         elif directions[1] == -1:
@@ -393,21 +397,6 @@ class Tools(object):
         self.moveDuration()
         return True
 
-    def stopMoveAll(self):
-        """
-        :return: success
-        """
-        self.app.mount.obsSite.stopMoveAll()
-        self.changeStyleDynamic(self.ui.moveNorth, 'running', False)
-        self.changeStyleDynamic(self.ui.moveNorthEast, 'running', False)
-        self.changeStyleDynamic(self.ui.moveEast, 'running', False)
-        self.changeStyleDynamic(self.ui.moveSouthEast, 'running', False)
-        self.changeStyleDynamic(self.ui.moveSouth, 'running', False)
-        self.changeStyleDynamic(self.ui.moveSouthWest, 'running', False)
-        self.changeStyleDynamic(self.ui.moveWest, 'running', False)
-        self.changeStyleDynamic(self.ui.moveNorthWest, 'running', False)
-        return True
-
     def setSlewSpeed(self):
         """
         :return: success
@@ -430,7 +419,7 @@ class Tools(object):
         if azimuthT is None or altitudeT is None:
             return False
 
-        azimuthT = altitudeT.degrees
+        azimuthT = azimuthT.degrees
         altitudeT = altitudeT.degrees
 
         if self.app.deviceStat['dome']:
@@ -443,10 +432,12 @@ class Tools(object):
 
         suc = self.app.mount.obsSite.startSlewing(slewType=slewType)
         if suc:
-            self.app.message.emit('Slewing mount', 0)
+            t = f'Slewing mount to:    Az:[{azimuthT:3.1f}], Alt:[{altitudeT:3.1f}]'
+            self.app.message.emit(t, 0)
 
         else:
-            self.app.message.emit('Cannot slew to: {azimuthT}, {altitudeT}', 2)
+            t = f'Cannot slew to:      Az:[{azimuthT:3.1f}], Alt:[{altitudeT:3.1f}]'
+            self.app.message.emit(t, 2)
         return suc
 
     def slewTargetAltAz(self, alt, az):
@@ -455,20 +446,26 @@ class Tools(object):
         :param az:
         :return:
         """
-        altHigh = self.app.mount.setting.horizonLimitHigh
-        altLow = self.app.mount.setting.horizonLimitLow
+        suc = self.app.mount.obsSite.setTargetAltAz(alt_degrees=alt,
+                                                    az_degrees=az)
+        if not suc:
+            t = f'Cannot set target :  Az:[{az:3.1f}], Alt:[{alt:3.1f}]'
+            self.app.message.emit(t, 2)
+            return False
 
-        if alt > altHigh:
-            alt = altHigh
-
-        elif alt < altLow:
-            alt = altLow
-
-        self.app.mount.obsSite.setTargetAltAz(alt_degrees=alt,
-                                              az_degrees=az)
         suc = self.slewSelectedTargetWithDome(slewType='keep')
         return suc
 
+    def moveAltAzDefault(self):
+        """
+        :return:
+        """
+        self.targetAlt = None
+        self.targetAz = None
+        for ui in self.setupMoveAltAz:
+            self.changeStyleDynamic(ui, 'running', False)
+        return True
+
     def moveAltAz(self):
         """
         :return:
@@ -477,21 +474,24 @@ class Tools(object):
         if ui not in self.setupMoveAltAz:
             return False
 
-        stat = self.app.mount.obsSite.status
         alt = self.app.mount.obsSite.Alt
         az = self.app.mount.obsSite.Az
 
-        if alt is None or az is None or stat is None:
-            return False
-
-        if stat not in [0, 7]:
+        if alt is None or az is None:
             return False
 
+        self.changeStyleDynamic(ui, 'running', True)
         key = list(self.setupStepsizes)[self.ui.moveStepSizeAltAz.currentIndex()]
         step = self.setupStepsizes[key]
         directions = self.setupMoveAltAz[ui]
-        targetAlt = alt.degrees + directions[0] * step
-        targetAz = az.degrees + directions[1] * step
+
+        if self.targetAlt is None or self.targetAz is None:
+            targetAlt = self.targetAlt = alt.degrees + directions[0] * step
+            targetAz = self.targetAz = az.degrees + directions[1] * step
+        else:
+            targetAlt = self.targetAlt = self.targetAlt + directions[0] * step
+            targetAz = self.targetAz = self.targetAz + directions[1] * step
+
         targetAz = targetAz % 360
         suc = self.slewTargetAltAz(targetAlt, targetAz)
         return suc
@@ -545,67 +545,22 @@ class Tools(object):
         self.ui.moveCoordinateDecFloat.setText(f'{value.degrees:2.4f}')
         return True
 
-    def checkAlt(self, alt):
-        """
-        :param alt:
-        :return:
-        """
-        if not alt:
-            return None
-
-        try:
-            alt = float(alt)
-
-        except Exception:
-            return None
-
-        if self.app.mount.setting.horizonLimitLow is None:
-            return None
-
-        if self.app.mount.setting.horizonLimitHigh is None:
-            return None
-
-        if alt > self.app.mount.setting.horizonLimitHigh:
-            return None
-
-        if alt < self.app.mount.setting.horizonLimitLow:
-            return None
-
-        return alt
-
-    @staticmethod
-    def checkAz(az):
-        """
-        :param az:
-        :return:
-        """
-        if not az:
-            return None
-
-        try:
-            az = float(az)
-
-        except Exception:
-            return None
-
-        az = (az + 360) % 360
-        return az
-
     def moveAltAzAbsolute(self):
         """
         :return:
         """
         alt = self.ui.moveCoordinateAlt.text()
-        alt = self.checkAlt(alt)
+        alt = valueToFloat(alt)
         if alt is None:
             return False
 
         az = self.ui.moveCoordinateAz.text()
-        az = self.checkAz(az)
+        az = valueToFloat(az)
         if az is None:
             return False
 
-        suc = self.slewTargetAltAz(float(alt), float(az))
+        az = (az + 360) % 360
+        suc = self.slewTargetAltAz(alt, az)
         return suc
 
     def moveRaDecAbsolute(self):
