@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -210,7 +210,7 @@ class Astrometry:
 
     def solveClear(self):
         """
-        the cyclic or long lasting tasks for solving the image should not run
+        the cyclic or long-lasting tasks for solving the image should not run
         twice for the same data at the same time. so there is a mutex to prevent
         his behaviour.
 
@@ -229,8 +229,8 @@ class Astrometry:
                        scaleHint=None, updateFits=False):
         """
         solveThreading is the wrapper for doing the solve process in a
-        threadpool environment of Qt. Otherwise the HMI would be stuck all the
-        time during solving. it is done with an securing mutex to avoid starting
+        threadpool environment of Qt. Otherwise, the HMI would be stuck all the
+        time during solving. it is done with a securing mutex to avoid starting
         solving twice. to solveClear is the partner of solve Threading
 
         :param fitsPath: full path to the fits image file to be solved
@@ -297,7 +297,7 @@ class Astrometry:
         name = self.run[self.framework].deviceName
         if sucApp and sucIndex:
             self.signals.deviceConnected.emit(name)
-            self.app.message.emit(f'ASTROMETRY found:    [{name}]', 0)
+            self.app.message.emit(f'PLATE SOLVER found:  [{name}]', 0)
 
         self.log.debug(f'Framework: [{self.framework}], {sucApp}, {sucIndex}')
         return True
@@ -309,5 +309,5 @@ class Astrometry:
         name = self.run[self.framework].deviceName
         self.signals.serverDisconnected.emit({name: 0})
         self.signals.deviceDisconnected.emit(name)
-        self.app.message.emit(f'ASTROMETRY remove:   [{name}]', 0)
+        self.app.message.emit(f'PLATE SOLVER remove: [{name}]', 0)
         return True
