@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -19,11 +19,11 @@
 import logging
 
 # external packages
-from PyQt5.QtTest import QTest
 from astropy.io import fits
 import numpy as np
 
 # local imports
+from gui.utilities.toolsQtWidget import sleepAndEvents
 from base.transform import JNowToJ2000
 from mountcontrol.convert import formatDstrToText
 
@@ -33,6 +33,8 @@ class CameraSupport:
     """
     __all__ = ['CameraSupport']
     log = logging.getLogger(__name__)
+    raJ2000 = None
+    decJ2000 = None
 
     def writeHeaderInfo(self, header, obs, expTime, binning, focalLength):
         """
@@ -72,15 +74,12 @@ class CameraSupport:
         header.append(('SQM',
                        self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS', 0)))
 
-        ra = obs.raJNow
-        dec = obs.decJNow
-        obsTime = obs.timeJD
-        isMount = ra is not None and dec is not None and obsTime is not None
-        isMount = isMount and obs.location is not None
+        hasCoordinate = self.raJ2000 is not None and self.decJ2000 is not None
+        isMount = obs.location is not None
+        if hasCoordinate:
+            header.append(('RA', self.raJ2000._degrees, 'Float value in degree'))
+            header.append(('DEC', self.decJ2000.degrees, 'Float value in degree'))
         if isMount:
-            ra, dec = JNowToJ2000(ra, dec, obsTime)
-            header.append(('RA', ra._degrees, 'Float value in degree'))
-            header.append(('DEC', dec.degrees, 'Float value in degree'))
             header.append(('TELESCOP', self.app.mount.firmware.product,
                            'Mount version from firmware'))
             lat = obs.location.latitude
@@ -142,13 +141,105 @@ class CameraSupport:
         """
         timeLeft = expTime
         while not function(param):
+            if self.abortExpose:
+                break
             text = f'expose {timeLeft:3.0f} s'
-            QTest.qWait(100)
+            sleepAndEvents(100)
+            self.signals.message.emit(text)
             if timeLeft >= 0.1:
                 timeLeft -= 0.1
             else:
                 timeLeft = 0
-            self.signals.message.emit(text)
+        return True
+
+    def waitStart(self):
+        """
+        :return:
+        """
+        while 'integrating' not in self.data.get('Device.Message'):
             if self.abortExpose:
                 break
+            sleepAndEvents(100)
+        return True
+
+    def waitIntegrate(self, timeLeft):
+        """
+        :param timeLeft:
+        :return:
+        """
+        while 'integrating' in self.data.get('Device.Message'):
+            if self.abortExpose:
+                break
+            text = f'expose {timeLeft:3.0f} s'
+            sleepAndEvents(100)
+            self.signals.message.emit(text)
+            if timeLeft >= 0.1:
+                timeLeft -= 0.1
+            else:
+                timeLeft = 0
+
+        self.signals.integrated.emit()
+        return True
+
+    def waitDownload(self):
+        """
+        :return:
+        """
+        self.signals.message.emit('download')
+        while 'downloading' in self.data.get('Device.Message'):
+            if self.abortExpose:
+                break
+            sleepAndEvents(100)
+
+        self.signals.downloaded.emit()
+        return True
+
+    def waitSave(self):
+        """
+        :return:
+        """
+        self.signals.message.emit('saving')
+        while 'image is ready' in self.data.get('Device.Message'):
+            if self.abortExpose:
+                break
+            sleepAndEvents(100)
+        return True
+
+    def waitFinish(self, function, param):
+        """
+        :param function:
+        :param param:
+        :return:
+        """
+        while not function(param):
+            if self.abortExpose:
+                break
+            sleepAndEvents(100)
+        return True
+
+    def waitCombinedSGPro(self, function, param, expTime):
+        """
+        :param function:
+        :param param:
+        :param expTime:
+        :return:
+        """
+        timeLeft = expTime
+        self.waitStart()
+        self.waitIntegrate(timeLeft)
+        self.waitDownload()
+        self.waitSave()
+        self.waitFinish(function, param)
+        return True
+
+    def waitCombinedNINA(self, expTime):
+        """
+        :param expTime:
+        :return:
+        """
+        timeLeft = expTime
+        self.waitStart()
+        self.waitIntegrate(timeLeft)
+        self.waitDownload()
+        self.waitSave()
         return True
